:github_url: https://github.com/tasts-robots/pink/tree/master/doc/src/references.rst

**********
References
**********

.. [BodyTaskJacobian] `Jacobian of a kinematic task and derivatives on manifolds <https://scaron.info/robotics/jacobian-of-a-kinematic-task-and-derivatives-on-manifolds.html>`_. S. Caron. 2023.

.. [MLT] `A micro Lie theory for state estimation in robotics <https://arxiv.org/abs/1812.01537>`_. J. Solà, J. Deray, D. Atchuthan. 2018.

.. [Sugihara2011] *Solvability-Unconcerned Inverse Kinematics by the Levenberg-Marquardt Method*. T. Sugihara. IEEE transactions on robotics, 2011, vol. 27, no 5, p. 984-991.
